from time import sleep
import RPA.Assistant
from RPA.Assistant.types import Icon, VerticalLocation, WindowLocation


assistant = RPA.Assistant.Assistant()


def next_ui(results):
    assistant.clear_dialog()
    assistant.add_heading("the 2nd ui")
    assistant.add_text(str(results))
    assistant.add_text_input(
        "txt_input", placeholder="placeholder", validation=length_greater_3
    )
    assistant.add_next_ui_button("the 3rd ui", third_ui)
    assistant.refresh_dialog()


def third_ui(results):
    assistant.clear_dialog()
    assistant.add_heading("the 3rd ui")
    assistant.add_text(str(results))
    assistant.add_text_input(
        "txt_input", placeholder="placeholder", validation=length_greater_3
    )
    assistant.add_next_ui_button("the 2nd ui", next_ui)
    assistant.refresh_dialog()


def length_greater_3(value):
    if len(value) <= 3:
        return "Length should be greater than 3"


import re


def validate_email(email):
    # E-mail specification is complicated, this matches that the e-mail has
    # at least one character before and after the @ sign, and at least one
    # character after the dot.
    regex = r"^.+@.+\..+"
    valid = re.match(regex, email)
    if not valid:
        return "Invalid email address"


def sleepy_print(arg):
    """used for testing is the button disabling working"""
    sleep(1)
    print(arg)


def manual():
    assistant.add_date_input("my_date", label="My Date")
    assistant.add_button(
        "python button",
        sleepy_print,
        "sleepy print output (should appear after ~1s sleep)",
    )
    assistant.add_button("robot button", "Log", "asd")
    assistant.add_next_ui_button("different form button", next_ui)
    assistant.add_heading("Heading test")
    assistant.add_text("Test")
    assistant.add_link("https://robocorp.com")
    assistant.add_icon(Icon.Failure)
    assistant.add_icon(Icon.Warning)
    assistant.add_icon(Icon.Success)

    assistant.add_flet_icon(icon="check_circle_rounded", color="FF00FF", size=48)

    assistant.add_text_input(
        "txt_input",
        placeholder="field with validation",
        required=True,
        validation=length_greater_3,
    )
    assistant.add_password_input("pw_input")
    assistant.add_checkbox("checkbox", "test_checkbox")
    assistant.add_file_input("file", file_type="pdf,png,jpg")
    assistant.add_hidden_input("Hidden", "value")
    assistant.add_text("Percentage slider")
    assistant.add_slider(
        name="percentage",
        slider_min=0,
        slider_max=100,
        steps=100,
        default=80,
        decimals=1,
    )
    # assistant.add_file(path="/Users/kerkko/Downloads/image.png", label="File")

    assistant.add_radio_buttons(
        name="user_type_radio",
        options="Admin,Maintainer,Operator",
        default="Operator",
        label="User type",
    )
    assistant.add_drop_down(
        name="user_type_dropdown",
        options="Admin,Maintainer,Operator",
        default="Operator",
        label="User type",
    )

    # assistant.add_dialog_next_page_button("Next page")
    assistant.add_text("List python files")
    assistant.add_files("src/**/*.py")
    assistant.add_image(
        "https://robocorp.com/assets/home/global-purple.svg", width=256, height=256
    )
    assistant.add_submit_buttons(["second submit"], "second submit")

    # assistant.clear_dialog()
    # assistant.add_icon(Icon.Failure)
    assistant.add_button(
        "clear elements",
        lambda: assistant.clear_dialog(),
        location=VerticalLocation.Right,
    )

    assistant.add_text_input(
        "txt_input_2", placeholder="placeholder", minimum_rows=2, maximum_rows=3
    )
    assistant.add_text_input("email", label="Email", validation=validate_email)
    assistant.add_loading_spinner("spinner")
    assistant.add_loading_bar("loading", width=100)

    results = assistant.run_dialog(location=WindowLocation.TopLeft, timeout=180)
    print(results)


if __name__ == "__main__":
    manual()



import pytest
from RPA.Assistant import Assistant
from RPA.Assistant.types import Icon, Location


def test_rows(assistant: Assistant):
    assistant.open_row()
    assistant.add_date_input("my_date", label="My Date")
    assistant.add_text("miscallenous text")
    assistant.close_row()


def test_container(assistant: Assistant):
    assistant.open_container()
    assistant.add_text("miscallenous text")
    assistant.close_container()


def test_top_bar(assistant: Assistant):
    assistant.open_navbar()
    assistant.add_text("miscallenous text")
    assistant.add_text("other text")
    assistant.close_navbar()


def test_column(assistant: Assistant):
    assistant.open_column()
    assistant.add_text("miscallenous text")
    assistant.close_column()


def test_container_multiple_content(assistant: Assistant):
    # with pytest.raises(ValueError):
    with pytest.raises(ValueError) as excinfo:
        assistant.open_container()
        assistant.add_text("test")
        assistant.add_text("test 2")
        assistant.close_container()

    assert "Attempting to place two content in one Container" in str(excinfo.value)


def test_empty_closing(assistant: Assistant):
    with pytest.raises(ValueError) as excinfo:
        assistant.close_row()
    assert "Cannot close Row, no open layout" in str(excinfo.value)


def test_double_navbar(assistant: Assistant):
    with pytest.raises(ValueError) as excinfo:
        assistant.open_navbar()
        assistant.open_navbar()
    assert "Only one navigation may be defined at a time" in str(excinfo.value)


def test_mixed_closing(assistant: Assistant):
    with pytest.raises(ValueError) as excinfo:
        assistant.open_container()
        assistant.close_row()

    assert "Cannot close" in str(excinfo.value)

    with pytest.raises(ValueError) as excinfo:
        assistant.open_row()
        assistant.close_container()

    assert "Cannot close" in str(excinfo.value)

    with pytest.raises(ValueError) as excinfo:
        assistant.open_navbar()
        assistant.close_container()

    assert "Cannot close" in str(excinfo.value)


def test_center_without_absolute_dimensions(assistant: Assistant):
    with pytest.raises(ValueError) as excinfo:
        assistant.open_stack(width=512, height=512)
        assistant.open_container(location=Location.Center)

    assert "Cannot determine centered position without static width and height" in str(
        excinfo.value
    )


def manual(assistant: Assistant):
    def print_controls():
        print(assistant._client.page.controls)

    assistant.open_navbar("nav")
    assistant.add_icon(Icon.Failure)
    assistant.add_button("test_button", print, "test")
    assistant.add_button("test_button", print, "test")
    assistant.add_button("print_controls", print_controls)
    assistant.add_button("clear dialog", assistant.clear_dialog)
    assistant.add_icon(Icon.Success)
    assistant.close_navbar()
    for i in range(5):

        # assistant.open_stack()

        assistant.open_container(40, 0, background_color="red500")
        assistant.open_row()

        assistant.open_stack()
        assistant.add_heading("column 1")
        assistant.open_container(left=0)
        assistant.add_text("asd")
        assistant.close_container()
        assistant.open_container(left=100, background_color="green500")
        assistant.add_text("testing 1")
        assistant.close_container()
        assistant.open_container(left=5, top=20, background_color="blue500")
        assistant.add_text("testing 2")
        assistant.close_container()
        assistant.close_stack()

        assistant.open_column()
        assistant.add_heading("column 2")
        assistant.add_text("testing 3")
        assistant.add_text("testing 4")
        assistant.close_column()
        assistant.close_row()
        assistant.close_container()

        # assistant.close_stack()
    assistant.run_dialog()


if __name__ == "__main__":
    manual(Assistant())



from time import sleep

import pytest
from RPA.Assistant import Assistant
from RPA.Assistant.types import PageNotOpenError


def test_set_title_no_page_open(assistant: Assistant):
    with pytest.raises(PageNotOpenError) as excinfo:
        assistant.set_title("test")
    assert "Set title called when page is not open" in str(excinfo.value)


def test_flet_update_no_page_open(assistant: Assistant):
    with pytest.raises(PageNotOpenError) as excinfo:
        assistant.refresh_dialog()
    assert "No page open when update_elements was called" in str(excinfo.value)


def test_duplicate_name_fails(assistant: Assistant):
    with pytest.raises(ValueError) as excinfo:
        assistant.add_text_input("one")
        assistant.add_text_input("one")
    assert "already in use" in str(excinfo.value)


def test_different_names_work(assistant: Assistant):
    assistant.add_text_input("one")
    assistant.add_text_input("two")
    assistant.add_text_input("three")



from robot.libraries import BuiltIn


class ExecutionContexts:
    def print_execution_context(self):
        from robot.running.context import EXECUTION_CONTEXTS

        current = EXECUTION_CONTEXTS.current
        print(current)
        BuiltIn.BuiltIn().log_to_console(current)
        return current



import sys
from pathlib import Path

from invoke import Collection

REPO_ROOT = Path(__file__).parents[2].resolve()
PACKAGE_DIR = REPO_ROOT / "packages" / "assistant"

# Note to VSCode users, in order to eliminate Pylance import errors
# in the IDE, you must add the following settings to your local project
# .vscode/settings.json file:
#
#     "python.analysis.extraPaths": [
#        "./invocations"
#    ]
sys.path.append(str(REPO_ROOT))
import invocations


configuration = {
    "is_meta": False,
    "package_dir": PACKAGE_DIR,
    "build_strategy": invocations.ROBOT_BUILD_STRATEGY,
}
ns: Collection = invocations.create_namespace(is_meta=False)
ns.configure(configuration)



from RPA.Assistant import Assistant
from RPA.Assistant.types import Location


assistant = Assistant()


def open_stack_layout():
    assistant.open_stack(width=512, height=512)
    assistant.open_container(width=72, height=72, location=Location.Center)
    assistant.add_heading("Stack")
    assistant.close_container()

    for value, loc in Location.__members__.items():
        assistant.open_container(
            width=72, height=72, location=loc, background_color="gray500"
        )
        assistant.add_text(value)
        assistant.close_container()

    assistant.close_stack()
    # The elements can go multiline and wider, so the 512 size stack doesn't quite fit
    # into a 512x512 dialog.
    assistant.run_dialog(width=512 + 60, height=512 + 60)


if __name__ == "__main__":
    open_stack_layout()



import datetime

from RPA.Assistant import Assistant


def test_slider(assistant: Assistant):
    assistant.add_slider("slider", default=51)
    results = assistant._get_results()
    assert results.get("slider") == 51


def test_slider_str_default(assistant: Assistant):
    assistant.add_slider("slider", default="50.07")
    results = assistant._get_results()
    assert results.get("slider") == 50.07


def test_text_input(assistant: Assistant):
    assistant.add_text_input("txt_input", default="text")
    results = assistant._get_results()
    assert results.get("txt_input") == "text"


def test_dropdown(assistant: Assistant):
    assistant.add_drop_down("dropdown", options=["mark", "monkey"], default="monkey")
    results = assistant._get_results()
    assert results.get("dropdown") == "monkey"


def test_date_input_date(assistant: Assistant):
    test_date = datetime.date(1993, 4, 26)
    assistant.add_date_input("testdate", default=test_date)
    results = assistant._get_results()
    assert results.get("testdate") == test_date


def test_date_input_string(assistant: Assistant):
    assistant.add_date_input("birthdate", default="1993-04-26")
    results = assistant._get_results()
    assert results.get("birthdate") == datetime.date(1993, 4, 26)


def test_radio_input(assistant: Assistant):
    assistant.add_radio_buttons("radio", options="First,Second", default="Second")
    results = assistant._get_results()
    assert results.get("radio") == "Second"


def test_dotdict_access(assistant: Assistant):
    assistant.add_text_input("txt_input", default="text")
    results = assistant._get_results()
    assert results.txt_input == "text"
    assert results["txt_input"] == "text"
    assert results.get("txt_input") == "text"


def test_checkbox_input(assistant: Assistant):
    assistant.add_checkbox("checkbox_true", "True", default=True)
    assistant.add_checkbox("checkbox_false", "False")
    results = assistant._get_results()
    assert results.checkbox_true is True
    assert results.checkbox_false is False
